summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/sound/flt_vol.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/sound/flt_vol.cpp')
-rw-r--r--src/devices/sound/flt_vol.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/devices/sound/flt_vol.cpp b/src/devices/sound/flt_vol.cpp
index eec55c413f8..8b8438f9b94 100644
--- a/src/devices/sound/flt_vol.cpp
+++ b/src/devices/sound/flt_vol.cpp
@@ -27,17 +27,17 @@ filter_volume_device::filter_volume_device(const machine_config &mconfig, const
void filter_volume_device::device_start()
{
m_gain = 0x100;
- m_stream = stream_alloc(1, 1, machine().sample_rate());
+ m_stream = stream_alloc_legacy(1, 1, machine().sample_rate());
}
//-------------------------------------------------
// sound_stream_update - handle a stream update
//-------------------------------------------------
-void filter_volume_device::sound_stream_update(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void filter_volume_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
- stream_sample_t *src = inputs[0];
+ stream_sample_t const *src = inputs[0];
stream_sample_t *dst = outputs[0];
while (samples--)
@@ -27,17 +27,17 @@ filter_volume_device::filter_volume_device(const machine_config &mconfig, const
}
//-------------------------------------------------
-// sound_stream_update - handle a stream update
+// sound_stream_update_legacy - handle a stream update
//-------------------------------------------------